sqlmesh.core.engine_adapter.databricks API documentation

Edit on GitHub

# sqlmesh.core.engine_adapter.databricks

View Source

    1from __future__ import annotations
    2
    3from sqlmesh.core.engine_adapter.spark import SparkEngineAdapter
    4
    5
    6class DatabricksSparkSessionEngineAdapter(SparkEngineAdapter):
    7    DIALECT = "databricks"

class DatabricksSparkSessionEngineAdapter(sqlmesh.core.engine_adapter.spark.SparkEngineAdapter): View Source

    7class DatabricksSparkSessionEngineAdapter(SparkEngineAdapter):
    8    DIALECT = "databricks"

Base class wrapping a Database API compliant connection.

The EngineAdapter is an easily-subclassable interface that interacts with the underlying engine and data store.

###### Arguments:

- connection_factory: a callable which produces a new Database API-compliant connection on every call.
- dialect: The dialect with which this adapter is associated.
- multithreaded: Indicates whether this adapter will be used by more than one thread.

##### Inherited Members

sqlmesh.core.engine_adapter.base.EngineAdapter
  EngineAdapter
  recycle
  close
  create_index
  create_table
  create_table_like
  drop_table
  create_view
  create_schema
  drop_schema
  drop_view
  columns
  table_exists
  delete_from
  insert_overwrite_by_time_partition
  update_table
  merge
  rename_table
  fetchone
  fetchall
  transaction
  execute
sqlmesh.core.engine_adapter.spark.SparkEngineAdapter
  fetchdf
  fetch_pyspark_df
  insert_append
sqlmesh.core.engine_adapter.base_spark.BaseSparkEngineAdapter
  replace_query
  create_state_table
  alter_table
  supports_transactions